pub struct CreateServerActivityOptions {
pub server_uuid: Uuid,
pub user_uuid: Option<Uuid>,
pub impersonator_uuid: Option<Uuid>,
pub api_key_uuid: Option<Uuid>,
pub schedule_uuid: Option<Uuid>,
pub event: CompactString,
pub ip: Option<IpNetwork>,
pub data: Value,
pub created: Option<NaiveDateTime>,
}Fields
server_uuid: Uuiduser_uuid: Option<Uuid>impersonator_uuid: Option<Uuid>api_key_uuid: Option<Uuid>schedule_uuid: Option<Uuid>event: CompactStringip: Option<IpNetwork>data: Valuecreated: Option<NaiveDateTime>Trait Implementations
Sourceimpl ComposeSchema for CreateServerActivityOptions
impl ComposeSchema for CreateServerActivityOptions
Sourceimpl<'de> Deserialize<'de> for CreateServerActivityOptions
impl<'de> Deserialize<'de> for CreateServerActivityOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for CreateServerActivityOptions
impl ToSchema for CreateServerActivityOptions
Sourceimpl Validate for CreateServerActivityOptions
impl Validate for CreateServerActivityOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for CreateServerActivityOptions
impl RefUnwindSafe for CreateServerActivityOptions
impl Send for CreateServerActivityOptions
impl Sync for CreateServerActivityOptions
impl Unpin for CreateServerActivityOptions
impl UnwindSafe for CreateServerActivityOptions